# unitorch.cli.models.bert

## BertProcessor

!!! tip
    **`core/process/bert`** is the section for configuration of BertProcessor.

::: unitorch.cli.models.bert.BertProcessor

## BertForClassification

!!! tip
    **`core/model/classification/bert`** is the section for configuration of BertForClassification.

::: unitorch.cli.models.bert.BertForClassification
